pygeodesy.utmupsBase.UtmUpsBase

Package pygeodesy :: Module utmupsBase :: Class UtmUpsBase |
[frames] | no frames]

# Class UtmUpsBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
                      UtmUpsBase

Known Subclasses:
  - utm.Utm
  - , ups.Ups

(INTERNAL) Base class for Utm and Ups coordinates.

Instance Methods
__init__(self, easting, northing, band='', datum=None, falsed=True, gamma=None, scale=None) (INTERNAL) New UtmUpsBase. |
__repr__(self) Default `repr(self)`. |
__str__(self) Default `str(self)`. |
eastingnorthing2(self, falsed=True) Return easting and northing, falsed or unfalsed. |
latFootPoint(self, northing=None, lat0=0, makris=False) Compute the foot-point latitude in `degrees`. |
phiFootPoint(self, northing=None, lat0=0, makris=False) Compute the foot-point latitude in `radians`. |
to2en(self, falsed=True) DEPRECATED, use method `eastingnorthing2`. |
toEpsg(self) Determine the EPSG (European Petroleum Survey Group) code. |
toMgrs(self, center=False) Convert this UTM/UPS coordinate to an MGRS grid reference. |
Inherited from `named._NamedBase`: `others`, `toRepr`, `toStr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| convergence DEPRECATED, use property `gamma`.
| datum Class `property` with a `.name` attribute.
| easting Get the easting (`meter`).
| eastingnorthing Get easting and northing (EasNor2Tuple`(easting, northing)`).
| falsed Are easting and northing falsed (`bool`)?
| falsed2 Must be overloaded.
| gamma Get the meridian convergence (`degrees`) or `None` if not available.
| hemisphere Get the hemisphere (`str`, 'N'|'S').
| northing Get the northing (`meter`).
| scale Get the grid scale (`float`) or `None`.
| scale0 Get the central scale factor (`float`).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, easting, northing, band='', datum=None, falsed=True, gamma=None, scale=None) (Constructor) |
(INTERNAL) New UtmUpsBase. Overrides: object.__init__

### __repr__ (self) (Representation operator) |
Default `repr(self)`. Overrides: object.__repr__ (inherited documentation)

### __str__ (self) (Informal representation operator) |
Default `str(self)`. Overrides: object.__str__ (inherited documentation)

### eastingnorthing2 (self, falsed=True) |
Return easting and northing, falsed or unfalsed. Arguments: `falsed` - If `True`, return easting and northing falsed, otherwise unfalsed (`bool`). Returns: An EasNor2Tuple`(easting, northing)` in `meter`.

### latFootPoint (self, northing=None, lat0=0, makris=False) |
Compute the foot-point latitude in `degrees`. Arguments: `northing` - Northing (`meter`, same units this ellipsoid's axes), overriding this northing, unfalsed. `lat0` - Geodetic latitude of the meridian's origin (`degrees`). `makris` - If `True`, use `Makris`' formula, otherwise `PyGeodetics`'. Returns: Foot-point latitude (`degrees`). See Also: PyGeodetics, FootpointLatitude, Makris and Geomatics' Mercator, page 60.

### phiFootPoint (self, northing=None, lat0=0, makris=False) |
Compute the foot-point latitude in `radians`. Returns: Foot-point latitude (`radians`). See Also: Method latFootPoint for further details.

### to2en (self, falsed=True) |
DEPRECATED, use method `eastingnorthing2`. Returns: An EasNor2Tuple`(easting, northing)`. Decorators: `@deprecated_method`

### toEpsg (self) |
Determine the EPSG (European Petroleum Survey Group) code. Returns: `EPSG` code (`int`). Raises: `EPSGError` - See Epsg.

### toMgrs (self, center=False) |
Convert this UTM/UPS coordinate to an MGRS grid reference. Arguments: `center` - If `True`, un-center this UTM or UPS to its `lowerleft` (`bool`) or by `center meter` (`scalar`). Returns: The MGRS grid reference (Mgrs). See Also: Function pygeodesy.toMgrs in module mgrs for more details. Note: If not specified, the latitudinal `band` is computed from the (geodetic) latitude and the `datum`.

Property Details

### convergence DEPRECATED, use property `gamma`. Get method: convergence(self) - DEPRECATED, use property `gamma`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### datum Class `property` with a `.name` attribute. Get method: datum(self) - Get the datum (Datum). Set method: datum(self, datum) - Set the (ellipsoidal) datum Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple).

### easting Get the easting (`meter`). Get method: easting(self) - Get the easting (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### eastingnorthing Get easting and northing (EasNor2Tuple`(easting, northing)`). Get method: eastingnorthing(self) - Get easting and northing (EasNor2Tuple`(easting, northing)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### falsed Are easting and northing falsed (`bool`)? Get method: falsed(self) - Are easting and northing falsed (`bool`)? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### falsed2 Must be overloaded. Get method: falsed2(self) - Must be overloaded. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### gamma Get the meridian convergence (`degrees`) or `None` if not available. Get method: gamma(self) - Get the meridian convergence (`degrees`) or `None` if not available. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### hemisphere Get the hemisphere (`str`, 'N'|'S'). Get method: hemisphere(self) - Get the hemisphere (`str`, 'N'|'S'). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### northing Get the northing (`meter`). Get method: northing(self) - Get the northing (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### scale Get the grid scale (`float`) or `None`. Get method: scale(self) - Get the grid scale (`float`) or `None`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### scale0 Get the central scale factor (`float`). Get method: scale0(self) - Get the central scale factor (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.